Struct DeviceInfo

pub struct DeviceInfo { /* private fields */ }
Information about a device that can be obtained without opening it.

Found in the results of crate::list_devices.

Platform-specific notes

  • Some fields are platform-specific
    • Linux: sysfs_path
    • Windows: instance_id, parent_instance_id, port_number, driver
    • macOS: registry_id, location_id

Implementations

Source

impl DeviceInfo

pub fn id(&self) -> DeviceId

Opaque identifier for the device.

pub fn sysfs_path(&self) -> &Path

(Linux-only) Sysfs path for the device.

pub fn busnum(&self) -> u8

(Linux-only) Bus number.

On Linux, the bus_id is an integer and this provides the value as u8.

pub fn port_chain(&self) -> &[u8]

Path of port numbers identifying the port where the device is connected.

Together with the bus ID, it identifies a physical port. The path is expected to remain stable across device insertions or reboots.

Since USB SuperSpeed is a separate topology from USB 2.0 speeds, a physical port may be identified differently depending on speed.

pub fn bus_id(&self) -> &str

Identifier for the bus / host controller where the device is connected.

pub fn device_address(&self) -> u8

Number identifying the device within the bus.

pub fn vendor_id(&self) -> u16

The 16-bit number identifying the device’s vendor, from the idVendor device descriptor field.

pub fn product_id(&self) -> u16

The 16-bit number identifying the product, from the idProduct device descriptor field.

pub fn device_version(&self) -> u16

The device version, normally encoded as BCD, from the bcdDevice device descriptor field.

pub fn usb_version(&self) -> u16

Encoded version of the USB specification, from the bcdUSB device descriptor field.

pub fn class(&self) -> u8

Code identifying the standard device class, from the bDeviceClass device descriptor field.

0x00: specified at the interface level.
0xFF: vendor-defined.

pub fn subclass(&self) -> u8

Standard subclass, from the bDeviceSubClass device descriptor field.

pub fn protocol(&self) -> u8

Standard protocol, from the bDeviceProtocol device descriptor field.

pub fn max_packet_size_0(&self) -> u8

Maximum packet size for endpoint zero.

pub fn speed(&self) -> Option<Speed>

Connection speed

pub fn manufacturer_string(&self) -> Option<&str>

Manufacturer string, if available without device IO.

Platform-specific notes
  • Windows: Windows does not cache the manufacturer string, and this will return None regardless of whether a descriptor exists.
pub fn product_string(&self) -> Option<&str>

Product string, if available without device IO.

pub fn serial_number(&self) -> Option<&str>

Serial number string, if available without device IO.

pub fn interfaces(&self) -> impl Iterator<Item = &InterfaceInfo>

Iterator over the device’s interfaces.

This returns summary information about the interfaces in the device’s active configuration for the purposes of matching devices prior to opening them.

Additional information about interfaces can be found in the configuration descriptor after opening the device by calling Device::active_configuration.

Platform-specific notes:
  • Windows: this is only available for composite devices bound to the usbccgp driver, and will be empty if the entire device is bound to a specific driver.
  • Windows: When interfaces are grouped by an interface association descriptor, this returns details from the interface association descriptor and does not include each of the associated interfaces.
pub fn open(&self) -> impl MaybeFuture<Output = Result<Device, Error>>

Open the device