pub enum TransferError {
Cancelled,
Stall,
Disconnected,
Fault,
InvalidArgument,
Unknown(u32),
}Expand description
Transfer error.
Variants
Cancelled
Transfer was cancelled or timed out.
Stall
Endpoint in a STALL condition.
This is used by the device to signal that an error occurred. For bulk
and interrupt endpoints, the stall condition can be cleared with
Endpoint::clear_halt. For control
requests, the stall is automatically cleared when another request is
submitted.
Disconnected
Device disconnected.
Fault
Hardware issue or protocol violation.
InvalidArgument
The request has an invalid argument or is not supported by this OS.
Unknown(u32)
Unknown or OS-specific error.
It won’t be considered a breaking change to map unhandled errors from
Unknown to one of the above variants. If you are matching on the
OS-specific code because an error is not correctly mapped, please open
an issue or pull request.