pub struct DeviceSelector { /* private fields */ }Expand description
A filter for matching devices in request_device.
Example
use nusb::{DeviceSelector, MaybeFuture};
let devices = nusb::request_device(&[
DeviceSelector::all().with_vid_pid(0x1234, 0x5678),
DeviceSelector::all().with_vid_pid(0x1111, 0x2222),
]).wait().unwrap();Implementations
Sourceimpl DeviceSelector
impl DeviceSelector
Sourcepub const fn all() -> DeviceSelector
pub const fn all() -> DeviceSelector
A selector that matches all devices.
Sourcepub const fn with_vid(self, vendor_id: u16) -> DeviceSelector
pub const fn with_vid(self, vendor_id: u16) -> DeviceSelector
Narrow the selector to only match devices with the given vendor ID.
Sourcepub const fn with_vid_pid(
self,
vendor_id: u16,
product_id: u16,
) -> DeviceSelector
pub const fn with_vid_pid( self, vendor_id: u16, product_id: u16, ) -> DeviceSelector
Narrow the selector to only match devices with the given vendor ID and product ID.
Sourcepub const fn with_class(self, class_code: u8) -> DeviceSelector
pub const fn with_class(self, class_code: u8) -> DeviceSelector
Narrow the selector to only match devices with the given class code.
Sourcepub const fn with_class_subclass(
self,
class_code: u8,
subclass_code: u8,
) -> DeviceSelector
pub const fn with_class_subclass( self, class_code: u8, subclass_code: u8, ) -> DeviceSelector
Narrow the selector to only match devices with the given class and subclass.
Sourcepub const fn with_class_subclass_protocol(
self,
class_code: u8,
subclass_code: u8,
protocol_code: u8,
) -> DeviceSelector
pub const fn with_class_subclass_protocol( self, class_code: u8, subclass_code: u8, protocol_code: u8, ) -> DeviceSelector
Narrow the selector to only match devices with the given class, subclass, and protocol.
Sourcepub fn with_serial_number(self, serial_number: String) -> DeviceSelector
pub fn with_serial_number(self, serial_number: String) -> DeviceSelector
Narrow the selector to only match devices with the given serial number.
Sourcepub fn product_id(&self) -> Option<u16>
pub fn product_id(&self) -> Option<u16>
Product ID, or None if not filtered by product ID.
Sourcepub fn serial_number(&self) -> Option<&str>
pub fn serial_number(&self) -> Option<&str>
Serial number, or None if not filtered by serial number.